Config

Struct Config 

pub struct Config {
    pub template_dir: String,
    pub templates: HashMap<String, String>,
    pub keep_typst_files: bool,
    pub template_parameters: HashMap<String, String>,
    pub chapter_imports: Option<String>,
    pub max_width: Option<f64>,
    pub max_height: Option<f64>,
}

Fields

template_dir: String

the typst template directory that holds all templates you can reference

templates: HashMap<String, String>

the list of template name and template file name. this tool will generate a pdf file for each template if no template is provided, it will generate a default pdf file without template.

keep_typst_files: bool

whether the intermidate typst files for each chapter should be kept or not.

template_parameters: HashMap<String, String>

parameter and value pairs for template use. you can define your value pair that match your template definition.

chapter_imports: Option<String>

option multi-lines string that can be imported at the beginning of each chapter. it’s very useful when you want to add the import statements for popular typst external functions.

max_width: Option<f64>

max_width in a floating number between 0.0 and 1.0 (include). this constraint will only be applied when the max height already meets the requirement.

max_height: Option<f64>

max_height in a floating number between 0.0 and 1.0 (include).

Implementations

Source

impl Config

pub fn get_chapter_full_file_name( &self, chapter: &Chapter, ctx: &RenderContext, ) -> Option<PathBuf>

pub fn get_chapter_relative_chapter_file_name( &self, chapter: &Chapter, _ctx: &RenderContext, ) -> Option<PathBuf>

pub fn append_chapter_to_typst_output( &self, ctx: &RenderContext, typst_output: &mut String, ) -> Result<()>

pub fn convert_book( &self, _chapter_file_list: &mut [PathBuf], ctx: &RenderContext, ) -> Result<()>

pub fn write_typst_file( &self, ctx: &RenderContext, typst_output: &str, template_name: Option<&str>, ) -> Result<()>

pub fn convert_book_to_pdf(&self, ctx: &RenderContext) -> Result<()>

pub fn invoke_typst_command( &self, ctx: &RenderContext, template_name: Option<&str>, ) -> Result<()>

Source

impl Config

pub fn parse_chapter_content( &self, chapter: &Chapter, content: &str, dst_file_path: &Path, image_parent_dir: &Path, ctx: &RenderContext, ) -> Result<String>

pub fn convert_chapters( &self, chapter_file_list: &mut Vec<PathBuf>, ctx: &RenderContext, ) -> Result<()>

Source

impl Config

Source

impl Config

pub fn get_book_name( &self, template_name: Option<&str>, ctx: &RenderContext, ) -> String

pub fn get_template_dir(&self, ctx: &RenderContext) -> PathBuf

pub fn get_typst_dir(&self, ctx: &RenderContext) -> PathBuf

pub fn get_pdf_dir(&self, ctx: &RenderContext) -> PathBuf

pub fn get_typst_templates_dir(&self, ctx: &RenderContext) -> PathBuf

pub fn get_chapters_dir(&self, ctx: &RenderContext) -> PathBuf

pub fn get_output_dir(&self, ctx: &RenderContext) -> PathBuf